package Hydropulser
  
  model Zusammenbau // Zusammenbau; Parameter koennen hier auch gesetzt werden!
    // Hier werden zunaechst die einzelnen Bloecke eingebaut
    Druckquelle druckquelle1(druck=5e05);
    Modelica.Blocks.Sources.Pulse anregung(period=2,offset=-0.5);  // Periodenzeit des Rechteckecksignals
    // Bauen Sie hier das Wegeventil mit Namen wegeventil1 ein!
    ....
    Rohr rohr1(zeta=1,L=1,d=0.005);
    Rohr rohr2(zeta=1,L=1,d=0.005); 
    Hydraulikzylinder hydraulikzylinder1(kappaeff=1.6e-9);                            
    // Bauen Sie hier einen Federdaempfer aus der Modelica Standardbibliothek ein und setzen Sie die Parameter!
    ....
    Modelica.Mechanics.Translational.Fixed lager1;
    Druckquelle tank1; // Keine Druckangabe noetig, da default druck=1e05 Pa (s. Modell Druckquelle)
   
    
    equation 
    // Verbindung der Komponenten
    connect(druckquelle1.stutzen_a, wegeventil1.stutzen_b1);
    connect(anregung.y, wegeventil1.position);
    connect(wegeventil1.stutzen_a1, rohr1.stutzen_b);
    connect(wegeventil1.stutzen_a2, rohr2.stutzen_b);
    
    connect(....., hydraulikzylinder1.stutzen_a);            // Hier fehlt noch ein Teil der Verbindung!!!
    connect(rohr2.stutzen_a, hydraulikzylinder1.stutzen_b);
    
    connect(federdaempfer1.flange_b, ......);                // Hier fehlt noch ein Teil der Verbindung!!!
    connect(federdaempfer1.flange_a, lager1.flange_b);
    
    connect(tank1.stutzen_a, wegeventil1.stutzen_b2); 
   
  end Zusammenbau;
    
  

  model Hydraulikzylinder  // Neues Hydraulikzylindermodell
    
    
    // Konnektoren einbauen
    Stutzen stutzen_a ;
    Stutzen stutzen_b ;
    Modelica.Mechanics.Translational.Interfaces.Flange_a flange_a ;
   
    
    // Setzen der Default-Parameter
    parameter Real pi=3.1414;
    parameter Real m(unit="kg")=0.3;
    parameter Real rho(unit="kg/m^3")=850;
    parameter Real A(unit="m^2")=pi/4*(15e-3)^2;
    parameter Real a(unit="m^2")=pi/4*(5e-3)^2;
    parameter Real L(unit="m")=0.5;
    parameter Real kappaeff(unit="1/Pa")=1.6e-09;
    parameter Real pu(unit="Pa")=1e5;
    //parameter Real c_anschlag(unit="N/m")=5e04;
    
    // Initialisieren der Variablen
    //Real Fbegr(unit="N");
    Real F(unit="N");
    Real z(unit="m",start=0.25);
    Real zpunkt(unit="m/s",start=0);
    Real p2(unit="Pa");
    Real p3(unit="Pa");
    Real q12(unit="m^3/s",start=0);
    Real q34(unit="m^3/s",start=0);
    
    
    equation 
    z   = flange_a.s;     //  Weg wird an Flansch uebergeben
    F = -flange_a.f;      //  Kraft wird an Flansch uebergeben
    p2  = stutzen_a.p;    //  Druck 1 wird an Stutzen 1 uebergeben
    p3  = stutzen_b.p;    //  Druck 4 wird an Stutzen 2 uebergeben
    q12 = -stutzen_a.Q;   //  Volumenstrom wird uebergeben...
    q34 = stutzen_b.Q;    //  auch...
    
    
    zpunkt = der(z);
    
    ...                                                   // Impulssatz hier einbauen!
    ...                                                 // Kontigleichung links hier!
    ...                                                 // Kontigleichung rechts...!
      
   ....                                                   // Aufgabenteil 2.1 c)
                                                           // Anschlagfeder bei 0.05 und 0.45 m implementieren!!! 
                                                          // Die auskommentierten Variablen Fbegr und 
                                                          // c_anschlag koennen dafuer benutzt werden...
    
  end Hydraulikzylinder;
  
   model Rohr   // Modell einer Rohrverbindung mit konstanter Druckverlustziffer
    Stutzen stutzen_a;
    Stutzen stutzen_b;
    parameter Real zeta;
    parameter Real rho=850;
    parameter Real L;
    parameter Real d;
    parameter Real lambda=zeta*d/L;
    Real dp;
    Real u;
    Real Q;
    equation
    u=Q/(3.14*(d/2)^2);   // Berechnung der mittleren Geschwindigkeit
    
    dp=zeta*(rho/2)*u*abs(u)+rho*L*der(u);      // Widerstandsgesetz
    
    stutzen_a.p-stutzen_b.p=dp;
    stutzen_a.Q=stutzen_b.Q;
    Q=stutzen_a.Q;
  end Rohr;
  
  
  
  
  connector Stutzen  // Konnektordefinition fuer Anschlussstutzen o. Verluste
    Real p;
    Real Q;
  end Stutzen;
  
  model Druckquelle        // Konstantdruck-"Quelle"
    Stutzen stutzen_a;
    parameter Real druck=1e05;
       
    equation 
    stutzen_a.p=druck;
    
  end Druckquelle;
  
  
  model Wegeventil         // 4-2-Wegeventil
    Stutzen stutzen_a1;
    Stutzen stutzen_a2;
    Stutzen stutzen_b1;
    Stutzen stutzen_b2;
    Real position;
        
    equation 
    stutzen_a1.p = if position>=0 then stutzen_b1.p else stutzen_b2.p;
    stutzen_a2.p = if position<0 then stutzen_b1.p else stutzen_b2.p;
    stutzen_a1.Q = if position>=0 then stutzen_b1.Q else stutzen_b2.Q;
    stutzen_a2.Q = if position<0 then stutzen_b1.Q else stutzen_b2.Q;
  
  end Wegeventil;
    
 


end Hydropulser;
